pyrecog
Pyrecog is a Python package that allows you to use image recognition by just having an image in the same folder as your code.
Functions:
	pyrecog.find() - Drag an image into the same folder as your code and this function will test to see if it's on screen.
Installing:
	pip install pyrecog
importing:
	import pyrecog